@@ -80,7 +80,7 @@ def fis_business_theme():
         'ytick.color':dark_blue,
         'axes.spines.left':False,
         'ytick.left': False,
-        'image.cmap': 'Greys',
+        'image.cmap': 'Blues',
     })
 
     sns.set_palette(business_colors)
@@ -97,7 +97,7 @@ def fis_business_theme():
     rcParams['grid.alpha'] = .5
     rcParams['axes.prop_cycle'] = cycler(color=business_colors)
     rcParams['grid.color'] = white
-    rcParams['image.cmap'] = 'Greys'
+    rcParams['image.cmap'] = 'Blues'
 
 def fis_get_colors(theme):
     if theme == 'light':
