@@ -11,8 +11,9 @@ def fis_time_elements(df):
     day = df.index.day
     minute = df.index.minute
     hour = df.index.hour
+    quarter = df.quarter
     
-    return(pd.DataFrame({'month':month,'year':year,'day':day,'minute':minute,'hour':hour}))
+    return(pd.DataFrame({'month':month,'year':year,'day':day,'minute':minute,'hour':hour,'quarter':quarter}))
     
 def fis_time_lags(df, num_lags = 7):
     """
